<?php

namespace Teknisa\MAN\Services;

use Doctrine\ORM\EntityManager;
use Teknisa\MAN\Utilities;

class RelEntregasPorMotoboyService {

	public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
    }
    
    public function fetchReport($conditions){
        $params = self::buildParams($conditions);
        return $this->entityManager->getConnection()->fetchAll(self::GET_ENTREGAS_POR_MOTOBOY_QRY, $params);
    }
    
    private function buildParams($conditions){
        if(array_key_exists('CDFILIAL', $conditions)){
            $conditions['CDFILIAL'] = implode('_', $conditions['CDFILIAL']);
            $conditions['TCDFILIAL'] = NULL;
        } else{
            $conditions['CDFILIAL'] = NULL;
            $conditions['TCDFILIAL'] = 'T';
        }
        if(array_key_exists('DTENTRVENDA', $conditions)){
            $conditions['DTINI'] = $conditions['DTENTRVENDA'][0];
            $conditions['DTFIN'] = $conditions['DTENTRVENDA'][1];
        }
        $params = array(
            ':CDFILIAL' =>  $conditions['CDFILIAL'],
            ':TCDFILIAL'=>  $conditions['TCDFILIAL'],
            ':DTINI'    =>  $conditions['DTINI'], 
            ':DTFIN'    =>  $conditions['DTFIN'], 
            ':NRORG'    =>  $conditions['NRORG']
        );
        return $params;
    }
    
    const GET_ENTREGAS_POR_MOTOBOY_QRY = "
        SELECT V.CDFILIAL, F.NMFILIAL, V.CDCAIXA, V.NRSEQVENDA, NVL(V.NRNOTAFISCALCE, V.NRCUPOMFIS) AS NRCUPOMFIS, V.DTVENDA, V.CDVENDEDOR, E.NMRAZSOCVEN,
          V.DSENDECONSVENDA, V.CDBAIRRO, NVL(V.DSBAIRRO,B.NMBAIRRO) AS NMBAIRRO, ENTG.NRENTREGAS, '1' AS QTDE, C.NMCONSUMIDOR, CAVR.VRVENDA , V.VRTXSEVENDA, EN.NRCELULARVEN, E.DSPLACAVEICULO,
          E.VRDIARIAVENDOR, V.CDFILIAL||' '||F.NMFILIAL AS LABELFILIAL, V.CDVENDEDOR||' '||E.NMRAZSOCVEN AS LABELMOTOQUEIRO
        FROM VENDA V 
         JOIN VENDEDOR E
           ON V.CDVENDEDOR   = E.CDVENDEDOR
            AND V.NRORG = E.NRORG
         LEFT JOIN BAIRRO B
          ON V.CDPAIS = B.CDPAIS
           AND V.SGESTADO = B.SGESTADO
           AND V.CDMUNICIPIO  = B.CDMUNICIPIO
           AND V.CDBAIRRO  = B.CDBAIRRO
           AND V.NRORG = B.NRORG
         JOIN FILIAL F
          ON V.CDFILIAL = F.CDFILIAL
           AND V.NRORG = F.NRORG
         JOIN CONSUMIDOR C 
          ON  V.CDCONSUMIDOR = C.CDCONSUMIDOR
          AND V.NRORG = C.NRORG
         LEFT JOIN ENDEVENDE EN
          ON V.CDVENDEDOR = EN.CDVENDEDOR
          AND V.NRORG = EN.NRORG
         JOIN (SELECT V.CDFILIAL, V.CDVENDEDOR, COUNT(V.CDFILIAL||V.CDCAIXA||V.NRSEQVENDA) AS NRENTREGAS, V.NRORG
               FROM VENDA V
               JOIN FILIAL F
                ON V.CDFILIAL = F.CDFILIAL 
                 AND V.NRORG = F.NRORG
               WHERE ((INSTR(:CDFILIAL, F.CDFILIAL) <> 0) OR (:TCDFILIAL = 'T'))
                 AND V.DTENTRVENDA BETWEEN :DTINI AND :DTFIN
                 AND V.NRENTREGAPEDVND IS NOT NULL
                 AND V.IDSITUVENDA = 'O'
               GROUP BY V.CDFILIAL, V.CDVENDEDOR, V.NRORG
              ) ENTG
          ON V.CDFILIAL = ENTG.CDFILIAL
           AND V.CDVENDEDOR   = ENTG.CDVENDEDOR
           AND V.NRORG = ENTG.NRORG
         JOIN ( SELECT V.CDFILIAL, V.CDCAIXA, V.NRSEQVENDA, SUM(ITV.QTPRODVEND * ITV.VRUNITVEND - ITV.VRDESITVEND + ITV.VRACRITVEND) AS VRVENDA, V.NRORG
                FROM VENDA V 
                JOIN ITEMVENDA ITV
                 ON  V.CDFILIAL    = ITV.CDFILIAL
                  AND V.CDCAIXA     = ITV.CDCAIXA
                  AND V.NRSEQVENDA  = ITV.NRSEQVENDA
                  AND V.NRORG  = ITV.NRORG
                JOIN FILIAL F
                 ON V.CDFILIAL = F.CDFILIAL 
                 AND V.NRORG = F.NRORG
               WHERE ((INSTR(:CDFILIAL, F.CDFILIAL) <> 0) OR (:TCDFILIAL = 'T'))
                 AND V.DTENTRVENDA BETWEEN :DTINI AND :DTFIN
                 AND V.NRENTREGAPEDVND IS NOT NULL    
                 AND V.IDSITUVENDA = 'O'      
              GROUP BY V.CDFILIAL, V.CDCAIXA, V.NRSEQVENDA, V.NRORG
              ) CAVR
          ON V.CDFILIAL = CAVR.CDFILIAL
           AND V.CDCAIXA = CAVR.CDCAIXA
           AND V.NRSEQVENDA = CAVR.NRSEQVENDA
           AND V.NRORG = CAVR.NRORG
        WHERE ((INSTR(:CDFILIAL, F.CDFILIAL) <> 0) OR (:TCDFILIAL = 'T'))
          AND V.IDSITUVENDA  = 'O'
          AND V.NRENTREGAPEDVND IS NOT NULL
          AND V.DTENTRVENDA BETWEEN :DTINI AND :DTFIN
          AND V.NRORG = :NRORG
        ORDER BY 
           V.CDFILIAL, V.CDVENDEDOR, V.DTVENDA
    ";
}